
# Metadata Generator

a metadata generator package in PHP , to use in projects or API.

## Options


key | types | description
---------|----------|---------
 title | string | website title
 themeColor | string | website theme color (used more on android devices to color the action bar)
 description | string | website description
 keywords | string | website keywords
 author | string | website author / creator / owner
 imageSrc | string | metadata image
 icon | string / string array | favicon url for the website or array with keys ("favicon" and "apple-touch-icon") to have different size icons for apple devices
 charset | string | wepage charset (default : UTF-8)
 canonical | string | canonical link of page
 prev | string | link of previous page (in pages with pagination if exists a previous page)
 next | string | link of next page (in pages with pagination if exists a next page)
 fbAdmins | string | fb id of page
 fbPageId | string | fb id of page
 type | string | type of page (article , video , ...)(see openGraph API)
 twCard | string | type of twitter card (default :  summary_large_image) 
 twCreator | string | author / creator / owner twitter user name
 [imageObj](#imageobj) | array | image object for openGraph API (could be same image as imageSrc but has to have more information)
 [videoObj](#videoobj) | array | video object for openGraph API 
 [audioObj](#audioobj) | array | audio object for openGraph API 
 locale | string | page language
 l10n | array string | languages that the page is available 
 siteName | string | webpage / website / company name
 [article](#article) | array | detailed info about the article (if type == article)
 [website](#website) | array | detailed info about the website
 [organization](#organization) | array | detailed info about the organization
 [breadcrumbs](#breadcrumbs) | array | info about the path of the page relative to home (a>b>c)
 [localbusiness](#local-business) | array | local business data


### Article
key | types | description
---------|----------|---------
authors | array |array with name of the authors or each author could be an array with the keys ( "name","facebook","twitter","instagram","linkedin", "website" ) 
publisher | string | link for publisher facebook page or other
pubDate | string | publication date
modDate | string | publication last modification date
dossier | string | dossier name
tags | array | tags names

### Local Business

[https://developers.google.com/search/docs/data-types/local-businesses](https://developers.google.com/search/docs/data-types/local-businesses)

key | types | description
---------|----------|---------
type | [BusinessType](#business-types) | type of business
url |  string | url of page of business
image |  array | array of url of images
priceRange | string | min and max price of stuff (used most for restaurants)
description | string | description of business
name | string | name of business
phone | string | phone number of business
email | string | email address of business
[address](#address) | array | address object of business 
[geo](#geographical-object) | array | geographical information
social |  array | array of social network links
cuisine | string | type of cuisine served in a food establishment
map | string | google maps url of business
schedule | array [DayOfWeek](#dayofweek) | opening/closing hours of the store/business
departments | (array) [localbusiness](#local-business) | in case of the business has more than one location or department



### Website

key | types | description
---------|----------|---------
name | string | name of the website
url |  string | website homepage link
social | array | array of social networks links 
search | boolean | set true for a search bar to appear when showing up in the results page of google
searchLink | string | endpoint of search request
searchQueryName | string | query param of search (default : "q")

### Organization

key | types | description
---------|----------|---------
name | string | name of the company/organization
url |  string | website of organization
social | array | array of social networks links 
logo | string | company logo 
contacts | array | array of arrays with keys (type , phone , email) where type is of type ContactType

### Breadcrumbs

breadcrumbs is an array of arrays composed by these values

key | types | description
---------|----------|---------
url |  string | url of page
name | string | name of the page
image | string | page image/logo

#### Address

key | types | description
---------|----------|---------
streetAddress | string | street name and door number
city | string | city name
region | string | district name
zipcode | string | zipcode
country | string | country name

#### Geographical Object

key | types | description
---------|----------|---------
latitude | string | latitude
longitude | string | longitude

#### DayOfWeek

key | types | description
---------|----------|---------
dayOfWeek | string | Day of week (Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday)
opens | string | closing hours of that day
closes| string | closing hours of that day


#### Business Types

possible business types for the moment (you have to import  : Helper\MetadataGenerator\StructuredData\LocalBusiness\BusinessType)
[https://docs.google.com/spreadsheets/d/1Ed6RmI01rx4UdW40ciWgz2oS_Kx37_-sPi7sba_jC3w/edit#gid=0](https://docs.google.com/spreadsheets/d/1Ed6RmI01rx4UdW40ciWgz2oS_Kx37_-sPi7sba_jC3w/edit#gid=0) 

Const | signature | value | 
---------|----------|---------
AnimalShelter | BusinessType::AnimalShelter | AnimalShelter
AutomotiveBusiness | BusinessType::AutomotiveBusiness | AutomotiveBusiness
ChildCare | BusinessType::ChildCare | ChildCare
Dentist | BusinessType::Dentist | Dentist
DryCleaningOrLaundry | BusinessType::DryCleaningOrLaundry | DryCleaningOrLaundry
EmergencyService | BusinessType::EmergencyService | EmergencyService
EmploymentAgency | BusinessType::EmploymentAgency | EmploymentAgency
EntertainmentBusiness | BusinessType::EntertainmentBusiness | EntertainmentBusiness
FinancialService | BusinessType::FinancialService | FinancialService
FoodEstablishment | BusinessType::FoodEstablishment | FoodEstablishment
GovernmentOffice | BusinessType::GovernmentOffice | GovernmentOffice
HealthAndBeautyBusiness | BusinessType::HealthAndBeautyBusiness | HealthAndBeautyBusiness
HomeAndConstructionBusiness | BusinessType::HomeAndConstructionBusiness | HomeAndConstructionBusiness
InternetCafe | BusinessType::InternetCafe | InternetCafe
LegalService | BusinessType::LegalService | LegalService
Library | BusinessType::Library | Library
LodgingBusiness | BusinessType::LodgingBusiness | LodgingBusiness
ProfessionalService | BusinessType::ProfessionalService | ProfessionalService
RadioStation | BusinessType::RadioStation | RadioStation
RealEstateAgent | BusinessType::RealEstateAgent | RealEstateAgent
RecyclingCenter | BusinessType::RecyclingCenter | RecyclingCenter
SelfStorage | BusinessType::SelfStorage | SelfStorage
ShoppingCenter | BusinessType::ShoppingCenter | ShoppingCenter
SportsActivityLocation | BusinessType::SportsActivityLocation | SportsActivityLocation
Store | BusinessType::Store | Store
TelevisionStation | BusinessType::TelevisionStation | TelevisionStation
TouristInformationCenter | BusinessType::TouristInformationCenter | TouristInformationCenter
TravelAgency | BusinessType::TravelAgency | TravelAgency
Bakery | BusinessType::Bakery | Bakery
BarOrPub | BusinessType::BarOrPub | BarOrPub
Brewery | BusinessType::Brewery | Brewery
CafeOrCoffeeShop | BusinessType::CafeOrCoffeeShop | CafeOrCoffeeShop
FastFoodRestaurant | BusinessType::FastFoodRestaurant | FastFoodRestaurant
IceCreamShop | BusinessType::IceCreamShop | IceCreamShop
Restaurant | BusinessType::Restaurant | Restaurant
Winery | BusinessType::Winery | Winery
BeautySalon | BusinessType::BeautySalon | BeautySalon
DaySpa | BusinessType::DaySpa | DaySpa
HairSalon | BusinessType::HairSalon | HairSalon
HealthClub | BusinessType::HealthClub | HealthClub
NailSalon | BusinessType::NailSalon | NailSalon
TattooParlor | BusinessType::TattooParlor | TattooParlor
AutoPartsStore | BusinessType::AutoPartsStore | AutoPartsStore
BikeStore | BusinessType::BikeStore | BikeStore
BookStore | BusinessType::BookStore | BookStore
ClothingStore | BusinessType::ClothingStore | ClothingStore
ComputerStore | BusinessType::ComputerStore | ComputerStore
ConvenienceStore | BusinessType::ConvenienceStore | ConvenienceStore
DepartmentStore | BusinessType::DepartmentStore | DepartmentStore
ElectronicsStore | BusinessType::ElectronicsStore | ElectronicsStore
Florist | BusinessType::Florist | Florist
FurnitureStore | BusinessType::FurnitureStore | FurnitureStore
GardenStore | BusinessType::GardenStore | GardenStore
GroceryStore | BusinessType::GroceryStore | GroceryStore
HardwareStore | BusinessType::HardwareStore | HardwareStore
HobbyShop | BusinessType::HobbyShop | HobbyShop
HomeGoodsStore | BusinessType::HomeGoodsStore | HomeGoodsStore
JewelryStore | BusinessType::JewelryStore | JewelryStore
LiquorStore | BusinessType::LiquorStore | LiquorStore
MensClothingStore | BusinessType::MensClothingStore | MensClothingStore
MobilePhoneStore | BusinessType::MobilePhoneStore | MobilePhoneStore
MovieRentalStore | BusinessType::MovieRentalStore | MovieRentalStore
MusicStore | BusinessType::MusicStore | MusicStore
OfficeEquipmentStore | BusinessType::OfficeEquipmentStore | OfficeEquipmentStore
OutletStore | BusinessType::OutletStore | OutletStore
PawnShop | BusinessType::PawnShop | PawnShop
PetStore | BusinessType::PetStore | PetStore
ShoeStore | BusinessType::ShoeStore | ShoeStore
SportingGoodsStore | BusinessType::SportingGoodsStore | SportingGoodsStore
TireShop | BusinessType::TireShop | TireShop
ToyStore | BusinessType::ToyStore | ToyStore
WholesaleStore | BusinessType::WholesaleStore | WholesaleStore

#### ContactType

possible contactTypes (you have to import  : Helper\MetadataGenerator\StructuredData\ContactType)


[https://developers.google.com/search/docs/data-types/corporate-contacts](https://developers.google.com/search/docs/data-types/corporate-contacts)

Const | signature | value | 
---------|----------|---------
CostumerSupport | 	ContactType::CostumerSupport | customer support
TechnicalSupport |	ContactType::TechnicalSupport | technical support
BillingSupport |	ContactType::BillingSupport | billing support
BillPayment |	ContactType::BillPayment | bill payment
Sales |	ContactType::Sales | sales
Reservations |	ContactType::Reservations | reservations
CreditCardSupport |	ContactType::CreditCardSupport | credit card support
Emergency |	ContactType::Emergency | emergency
BaggageTracking |	ContactType::BaggageTracking | baggage tracking
RoadsideAssistance |	ContactType::RoadsideAssistance | roadside assistance
PackageTracking |	ContactType::PackageTracking | package tracking


### ImageOBJ

key | types | description
---------|----------|---------
url | string | url of the image
secure_url | string | https url of image
type | string | MIME-Type of image (ex : image/jpg)
width | string | width in pixels of image
height | string | height in pixels of image
alt | string | alt text of image

### VideoOBJ

key | types | description
---------|----------|---------
url | string | url of the video
secure_url | string | https url of video
type | string | MIME-Type of video (ex : video/mp4)
width | string | width in pixels of video
height | string | height in pixels of video
duration | string | duration of the video in seconds


### AudioOBJ

key | types | description
---------|----------|---------
url | string | url of the audio
secure_url | string | https url of audio
type | string | MIME-Type of audio (ex : audio/mp4)

## Methods

all methods return the html to print in your webpage 

name | signature |  description
---------|----------|---------
General | getGeneralMetadata($options,$format) | prints the general metadata tags of a webpage
OpenGraph | getOpenGraphMetadata($options,$format) | prints the metatags required for openGraph API Sharing
GooglePlus | getGooglePlusMetadata($options,$format) | prints the metatags required for Google plus Sharing
Twitter| getTwitterMetadata($options,$format) | prints the metatags required for Twitter Sharing
StructuredData | getStructuredData($options,$format) | prints structured data in JSON+LD
All | getAllMetadata($options,$format) | prints all metadata calling all the methods above

## Example

```
require("../../vendor/autoload.php");
use Helper\MetadataGenerator\MetadataGenerator;
use Helper\MetadataGenerator\StructuredData\ContactType;

$options = [
	"title" => 'Informação - FamaTV',
	"themeColor" => "#72B946",
	"description" => 'A FamaTV é um projeto pioneiro na webtv nacional e assume agora uma nova imagem.',
	"keywords" => "Famalicão e assim",
	"author" => "Pedro Silva",
	"imageSrc" => "http://famatv.youoncontent.com/resources/img/metadata/metadata-famatv.png",
	"icon" => ["favicon" => "http://famatv.youoncontent.com/resources/img/favicon-famatv.png",
				"apple-touch-icon" => "http://famatv.youoncontent.com/resources/img/favicon-famatv.png" ],
	"charset" => "utf-8",
	"canonical" => "http://famatv.youoncontent.com/videos/informacao/pagina/2/",
	"prev" => "http://famatv.youoncontent.com/videos/informacao/",
	"next" => "http://famatv.youoncontent.com/videos/informacao/pagina/3/",
	"fbAdmins" => "181488158850210",
	"fbPageId" => "181488158850210",
	"type" =>  "article",
	"twCard" => "summary_large_image",
	"twCreator" => "@youongroup",
	"twSite" => "@youongroup",
	"imageObj" =>  [
		"url" => "http://famatv.youoncontent.com/resources/img/metadata/metadata-famatv.png",
		"secure_url" => "https://famatv.youoncontent.com/resources/img/metadata/metadata-famatv.png",
		"type" => "image/png",
		"width" => "800",
		"height" => "450",
		"alt" => "some random description"
	],
	"locale" => "pt",
	"l10n" => ["pt","en","es"],
	"siteName" => "FamaTv",
	"article" => [
		"authors" => [
		
			[
			"name" => "Jorge Mendes Menezes Magalhães",
			"facebook" => "http://facebook.com/1234",
			"website" =>  "http://www.t.pt"
			],
			[
			"name" => "Samsung",
			"facebook" => "http://www.l.pt",
			"twitter" => "http://www.i.pt",
			"instagram" => "http://www.sapo.pt",
			"linkedin" => "http://www.i.pt",
			"website" =>  "http://www.t.pt"
			],
			[
			"name" => "Samsung 2",
			"instagram" => "http://www.sapo.pt",
		]
		],
		"publisher" => "http://facebook.com/1234",
		"pubDate" => "2013-09-17T05:59:00+01:00",
		"modDate" => "2013-09-17T05:59:00+01:00",
		"dossier" => "Informação",
		"tags" => [
		"Seniores", "Fátima"
		]
	],
	"website" => [
      "name" => "FamaTv",
      "url" => "http://famatv.youoncontent.com/",
      "social" => [
        "https://www.facebook.com/famatv.famalicao/",
        "https://www.twitter.com/famatv.famalicao/",
        "https://www.instagram.com/famatv.famalicao/",
        "https://www.linkedin.com/famatv.famalicao/",
      ],
      "search" => true,
      "searchLink" => "http://famatv.youoncontent.com/pesquisa/",
      "searchQueryName" => "q"
    ],
    "organization" => [
      "name" => "FamaTv Inc",
      "url" => "http://famatv.youoncontent.com/",
      "social" => [
        "https://www.facebook.com/famatv.famalicao/",
        "https://www.twitter.com/famatv.famalicao/",
        "https://www.instagram.com/famatv.famalicao/",
        "https://www.linkedin.com/famatv.famalicao/",
      ],
      "logo" => "",
      "contacts" => [
        [
          "type" => ContactType::CostumerSupport,
          "phone" => "+351 252 123 456",
          "email" => "email@rroba.milho",
        ]
      ]
    ],
   "breadcrumbs" => [
      [
        "url" => "http://famatv.youoncontent.com/",
        "name" => "FamaTv",
        "image"=> "http://famatv.youoncontent.com/resources/img/favicon-famatv.png"
      ],
      [
        "url" => "http://famatv.youoncontent.com/level1",
        "name" => "level 1",
        "image"=> "http://famatv.youoncontent.com/resources/img/favicon-famatv.png"
      ],
      [
        "url" => "http://famatv.youoncontent.com/level1/level2",
        "name" => "level 2",
        "image"=> "http://famatv.youoncontent.com/resources/img/favicon-famatv.png"
      ],

    ],
	"localbusiness" => [
      "type" => BusinessType::Restaurant,
      "url" => "http://www.donamariapregaria.pt/",
      "image"=> [
        "http://www.donamariapregaria.pt/resources/img/metadata/metadata-pregaria-home-contactos.png"
      ],
      "priceRange" => "10€ - 20€",
      "description" => "De origem tradicional ... A Dona Maria Pregaria nasce em Famalicão com o objetivo de redefinir o conceito do Prego Português e do Hambúrguer Artesanal, com receitas diversificadas e originais que vão desde a mais tradicional à mais elaborada de gosto sofisticado.",
      "name" => "Dona maria Pregaria - Famalicão",
      "phone" => "+351252313623",
      "email" => "",
      "address" => [
        "streetAddress" => "Praça Dona Maria II 410",
        "city" => "Vila Nova de Famalicão",
        "region" => "braga",
        "zipcode" => "4760-111",
        "country" => "Portugal"
      ],
      "geo" => [
        "latitude" => "41.4046119",
        "longitude" => "-8.5185725"
      ],
      "social" => [
        "https://www.facebook.com/Donamariapregaria",
        "https://www.instagram.com/donamariapregaria"
      ],
      "cuisine" => "Hamburgers and Pregos",
      "map" => "https://www.google.com/maps/place/Dona+Maria+Pregaria/@41.4046985,-8.5203193,17z/data=!3m1!4b1!4m5!3m4!1s0xd2458f86a21ffad:0xfb02ac09b4d2c2ba!8m2!3d41.4046985!4d-8.5181306",
      "schedule" => [

        [
          "dayOfWeek" => "Monday",
          "opens" => "12:00",
          "closes"=> "15:00"
        ],
        [
          "dayOfWeek" => "Monday",
          "opens" => "18:00",
          "closes"=> "23:00"
        ],
        [
          "dayOfWeek" => "Tuesday",
          "opens" => "18:00",
          "closes"=> "23:00"
        ],
        [
          "dayOfWeek" => "Wednesday",
          "opens" => "18:00",
          "closes"=> "23:00"
        ],
        [
          "dayOfWeek" => "Thursday",
          "opens" => "18:00",
          "closes"=> "23:00"
        ],
        [
          "dayOfWeek" => "Friday",
          "opens" => "18:00",
          "closes"=> "23:00"
        ]
      ],
      "departments" => [
        [
          "name" => "Dona maria Pregaria - Porto",
          "phone" => "+351223271112",
          "email" => "",
          "address" => [
            "streetAddress" => "R. de Ceuta 63",
            "city" => "Porto",
            "region" => "Porto",
            "zipcode" => "4050-189 Porto",
            "country" => "Portugal"
          ],
          "geo" => [
            "latitude" => "41.1482368",
            "longitude" => "-8.6161672"
          ],
          "map" => "https://www.google.com/maps/place/Dona+Maria+Pregaria/@41.1482368,-8.6161672,17z/data=!4m13!1m7!3m6!1s0xd2464e2dad1dfa7:0xe96d49ce64b5db81!2sR.+de+Ceuta+63,+Porto,+Portugal!3b1!8m2!3d41.1482368!4d-8.6139785!3m4!1s0xd2464e2cff9163d:0xc043a589b1c26be1!8m2!3d41.1483025!4d-8.6140282"
        ]
        
      ]
   ]
];

$generator = new MetadataGenerator();

define("DEBUG",true)
echo $generator->getGeneralMetadata($data,DEBUG); 
echo $generator->getOpenGraphMetadata($data,DEBUG); 
echo $generator->getGooglePlusMetadata($data,DEBUG); 
echo $generator->getTwitterMetadata($data,DEBUG); 
echo $generator->getStructuredData($data,DEBUG);

```

## Resulting JSON-LD

* testing url
[https://search.google.com/structured-data/testing-tool](https://search.google.com/structured-data/testing-tool)

```

<script type="application/ld+json"> [{"@context":"http:\/\/schema.org","@type":"WebSite","url":"http:\/\/famatv.youoncontent.com\/","image":"http:\/\/famatv.youoncontent.com\/resources\/img\/metadata\/metadata-famatv.png","potentialAction":{"@type":"SearchAction","target":"http:\/\/famatv.youoncontent.com\/pesquisa\/?q={search_term_string}","query-input":"required name=search_term_string"},"sameAs":["https:\/\/www.facebook.com\/famatv.famalicao\/","https:\/\/www.twitter.com\/famatv.famalicao\/","https:\/\/www.instagram.com\/famatv.famalicao\/","https:\/\/www.linkedin.com\/famatv.famalicao\/"]},{"@context":"http:\/\/schema.org","@type":"Organization","url":"http:\/\/famatv.youoncontent.com\/","name":"FamaTv Inc","logo":"","contactPoint":[{"@type":"ContactPoint","contactType":"customer support","telephone":"+351 252 123 456","email":"email@rroba.milho"}]},{"@context":"http:\/\/schema.org","@type":"BreadcrumbList","itemListElement":[{"@type":"ListItem","position":1,"item":{"@id":"http:\/\/famatv.youoncontent.com\/","name":"FamaTv","image":"http:\/\/famatv.youoncontent.com\/resources\/img\/favicon-famatv.png"}},{"@type":"ListItem","position":2,"item":{"@id":"http:\/\/famatv.youoncontent.com\/level1","name":"level 1","image":"http:\/\/famatv.youoncontent.com\/resources\/img\/favicon-famatv.png"}},{"@type":"ListItem","position":3,"item":{"@id":"http:\/\/famatv.youoncontent.com\/level1\/level2","name":"level 2","image":"http:\/\/famatv.youoncontent.com\/resources\/img\/favicon-famatv.png"}}]},{"@context":"http:\/\/schema.org","@type":"Restaurant","@id":"http:\/\/www.donamariapregaria.pt\/","url":"http:\/\/www.donamariapregaria.pt\/","description":"De origem tradicional ... A Dona Maria Pregaria nasce em Famalic\u00e3o com o objetivo de redefinir o conceito do Prego Portugu\u00eas e do Hamb\u00farguer Artesanal, com receitas diversificadas e originais que v\u00e3o desde a mais tradicional \u00e0 mais elaborada de gosto sofisticado.","name":"Dona maria Pregaria - Famalic\u00e3o","image":["http:\/\/www.donamariapregaria.pt\/resources\/img\/metadata\/metadata-pregaria-home-contactos.png"],"sameAs":["https:\/\/www.facebook.com\/Donamariapregaria","https:\/\/www.instagram.com\/donamariapregaria"],"telephone":"+351252313623","email":"","geo":{"@type":"GeoCoordinates","latitude":"41.4046119","longitude":"-8.5185725"},"address":{"@type":"PostalAddress","streetAddress":"Pra\u00e7a Dona Maria II 410","addressLocality":"Vila Nova de Famalic\u00e3o","addressRegion":"braga","postalCode":"4760-111","addressCountry":"Portugal"},"openingHoursSpecification":[{"@type":"OpeningHoursSpecification","dayOfWeek":["Monday"],"opens":"12:00","closes":"15:00"},{"@type":"OpeningHoursSpecification","dayOfWeek":["Monday","Tuesday","Wednesday","Thursday","Friday"],"opens":"18:00","closes":"23:00"}],"priceRange":"10\u20ac - 20\u20ac","servesCuisine":"Hamburgers and Pregos","hasMap":"https:\/\/www.google.com\/maps\/place\/Dona+Maria+Pregaria\/@41.4046985,-8.5203193,17z\/data=!3m1!4b1!4m5!3m4!1s0xd2458f86a21ffad:0xfb02ac09b4d2c2ba!8m2!3d41.4046985!4d-8.5181306","department":[{"@context":"http:\/\/schema.org","@type":"Restaurant","name":"Dona maria Pregaria - Porto","image":["http:\/\/www.donamariapregaria.pt\/resources\/img\/metadata\/metadata-pregaria-home-contactos.png"],"telephone":"+351223271112","email":"","geo":{"@type":"GeoCoordinates","latitude":"41.1482368","longitude":"-8.6161672"},"address":{"@type":"PostalAddress","streetAddress":"R. de Ceuta 63","addressLocality":"Porto","addressRegion":"Porto","postalCode":"4050-189 Porto","addressCountry":"Portugal"},"priceRange":"10\u20ac - 20\u20ac","servesCuisine":"Hamburgers and Pregos","hasMap":"https:\/\/www.google.com\/maps\/place\/Dona+Maria+Pregaria\/@41.1482368,-8.6161672,17z\/data=!4m13!1m7!3m6!1s0xd2464e2dad1dfa7:0xe96d49ce64b5db81!2sR.+de+Ceuta+63,+Porto,+Portugal!3b1!8m2!3d41.1482368!4d-8.6139785!3m4!1s0xd2464e2cff9163d:0xc043a589b1c26be1!8m2!3d41.1483025!4d-8.6140282"}]},{"@context":"http:\/\/schema.org","@type":"NewsArticle","mainEntityOfPage":{"@type":"WebPage","@id":"http:\/\/famatv.youoncontent.com\/videos\/informacao\/pagina\/2\/"},"headline":"Informa&ccedil;&atilde;o - FamaTV","image":["http:\/\/famatv.youoncontent.com\/resources\/img\/metadata\/metadata-famatv.png"],"datePublished":"2013-09-17T05:59:00+01:00","dateModified":"2013-09-17T05:59:00+01:00","description":"A FamaTV &eacute; um projeto pioneiro na webtv nacional e assume agora uma nova imagem.","publisher":{"@type":"Organization","name":"FamaTv","logo":{"@type":"ImageObject","url":"http:\/\/famatv.youoncontent.com\/resources\/img\/favicon-famatv.png"}},"author":[{"@type":"Person","name":"Jorge Mendes Menezes Magalh&atilde;es"},{"@type":"Person","name":"Samsung"},{"@type":"Person","name":"Samsung 2"}]}]</script>



```

### interesting links

* [https://github.com/audreyr/favicon-cheat-sheet](https://github.com/audreyr/favicon-cheat-sheet)
* [https://developers.google.com/search/docs/data-types/articles](https://developers.google.com/search/docs/data-types/articles)
* [https://developers.google.com/search/docs/data-types/job-postings](https://developers.google.com/search/docs/data-types/job-postings)
* [https://developers.google.com/search/docs/data-types/events](https://developers.google.com/search/docs/data-types/events)
* [https://developers.google.com/search/docs/data-types/reviews](https://developers.google.com/search/docs/data-types/reviews)
* [https://developers.google.com/search/docs/data-types/breadcrumbs](https://developers.google.com/search/docs/data-types/breadcrumbs)
